# Authentication provider using Synology DSM users for Home Assistant

## License & attribution

Apache v2.0

Test utilities under `tests` are coming from [Home Assistant Core](https://github.com/home-assistant/core).
